function pu = getBrinch(gamma, b, z, phi, c)
% determines the ultimate lateral resistance per Brinch Hansen method

% pressure at ground surface
Kqo = exp((pi/2 + phi)*tan(phi))*cos(phi)*tan(pi/4 + phi/2) ...
      - exp(-(pi/2 - phi)*tan(phi))*cos(phi)*tan(pi/4 - phi/2);

Kco = cot(phi)*(exp((pi/2 + phi)*tan(phi))*cos(phi)*tan(pi/4 + phi/2) - 1);

% pressure at great depth
dcinf = 1.58 + 4.09*(tan(phi))^4;
Nc = cot(phi)*(exp(pi*tan(phi))*(tan(pi/4 + phi/2))^2 -1);
Ko = 1 - sin(phi);
Kcinf = Nc*dcinf;
Kqinf = Kcinf*Ko*tan(phi);

% pressure at an arbitary depth
zb = z/b;
aq = (Kqo/(Kqinf - Kqo))*(Ko*sin(phi)/sin(pi/4 + phi/2));
KqD = (Kqo + Kqinf*aq*zb)./(1 + aq*zb);

ac = (Kco/(Kcinf - Kco))*2*sin(pi/4 + phi/2);
KcD = (Kco + Kcinf*ac*zb)./(1 + ac*zb);

pu = (gamma*z.*KqD + c*KcD)*b;

return